@@ -1,4 +1,4 @@
-use std::rc::{Rc};
+use std::{sync::Arc};
 
 use crate::hashed_password::BaseHashedPassword;
 
@@ -6,7 +6,7 @@ use super::hashed_password::HashedPassword;
 
 pub trait ClearTextPassword { 
     fn text(&self) -> Result<String, std::io::Error>;
-    fn hashed_password(&self) -> Result<Rc<dyn HashedPassword>, std::io::Error>;
+    fn hashed_password(&self) -> Result<Arc<dyn HashedPassword>, std::io::Error>;
 }
 
 pub struct BaseClearTextPassword { 
@@ -18,8 +18,8 @@ impl ClearTextPassword for BaseClearTextPassword {
         Ok(String::from("something"))
     }
 
-    fn hashed_password(&self) -> Result<Rc<dyn HashedPassword>, std::io::Error> { 
-        Ok(Rc::new(BaseHashedPassword{}))
+    fn hashed_password(&self) -> Result<Arc<dyn HashedPassword>, std::io::Error> { 
+        Ok(Arc::new(BaseHashedPassword{}))
     }
 }
 
