@@ -1,17 +1,17 @@
-use std::{rc::Rc};
+use std::{sync::Arc};
 
 use crate::{user::{User, BaseUser}, hashed_password::{HashedPassword, BaseHashedPassword}, clear_text_password::{ClearTextPassword, BaseClearTextPassword}, public_key::PublicKey};
 
 pub trait UserFactory { 
-    fn create(&self, public_key: PublicKey, hashed_password: Rc<dyn HashedPassword>) -> Rc<dyn User>;
+    fn create(&self, public_key: PublicKey, hashed_password: Arc<dyn HashedPassword>) -> Arc<dyn User>;
 }
 
 pub trait HashedPasswordFactory { 
-    fn create(&self) -> Rc<dyn HashedPassword>;
+    fn create(&self) -> Arc<dyn HashedPassword>;
 }
 
 pub trait ClearTextPasswordFactory { 
-    fn create(&self, text: String) -> Rc<dyn ClearTextPassword>;
+    fn create(&self, text: String) -> Arc<dyn ClearTextPassword>;
 }
 
 pub struct UserFactoryImpl { 
@@ -19,8 +19,8 @@ pub struct UserFactoryImpl {
 }
 
 impl UserFactory for UserFactoryImpl { 
-    fn create(&self, public_key: PublicKey, hashed_password: Rc<dyn HashedPassword>) -> Rc<dyn User> { 
-        Rc::new(BaseUser::new(public_key, hashed_password)) 
+    fn create(&self, public_key: PublicKey, hashed_password: Arc<dyn HashedPassword>) -> Arc<dyn User> { 
+        Arc::new(BaseUser::new(public_key, hashed_password)) 
     }
 }
 
@@ -29,8 +29,8 @@ pub struct HashedPasswordFactoryImpl {
 }
 
 impl HashedPasswordFactory for HashedPasswordFactoryImpl { 
-    fn create(&self) -> Rc<dyn HashedPassword>{ 
-        Rc::new(BaseHashedPassword::new())
+    fn create(&self) -> Arc<dyn HashedPassword>{ 
+        Arc::new(BaseHashedPassword::new())
     }
 }
 
@@ -39,7 +39,7 @@ pub struct ClearTextPasswordFactoryImpl {
 }
 
 impl ClearTextPasswordFactory for ClearTextPasswordFactoryImpl { 
-    fn create(&self, text: String) -> Rc<dyn ClearTextPassword> { 
-        Rc::new(BaseClearTextPassword::new(text))
+    fn create(&self, text: String) -> Arc<dyn ClearTextPassword> { 
+        Arc::new(BaseClearTextPassword::new(text))
     } 
 }
