@@ -1,7 +1,7 @@
-use std::rc::Rc;
+use std::{sync::Arc};
 
 pub trait HashedPassword { 
-    fn equals(&self, hashed_password: Rc<dyn HashedPassword>) -> Result<bool, std::io::Error>;
+    fn equals(&self, hashed_password: Arc<dyn HashedPassword>) -> Result<bool, std::io::Error>;
 }
 
 pub struct BaseHashedPassword { 
@@ -9,7 +9,7 @@ pub struct BaseHashedPassword {
 }
 
 impl HashedPassword for BaseHashedPassword { 
-    fn equals(&self, hashed_password: Rc<dyn HashedPassword>) -> Result<bool, std::io::Error> { 
+    fn equals(&self, hashed_password: Arc<dyn HashedPassword>) -> Result<bool, std::io::Error> { 
         Ok(true) 
     }
 }
