@@ -1,21 +1,21 @@
-use std::{rc::Rc, hash::Hash};
+use std::{sync::Arc};
 
 use crate::{token::Token, hashed_password::HashedPassword, public_key::PublicKey, clear_text_password::ClearTextPassword};
 
 
 pub trait User { 
-    fn authenticate(&self, clear_text_password: Rc<dyn ClearTextPassword>) -> Result<(), std::io::Error>;
+    fn authenticate(&self, clear_text_password: Arc<dyn ClearTextPassword>) -> Result<(), std::io::Error>;
     fn token(&self) -> Token;
-    fn hashed_password(&self) -> Rc<dyn HashedPassword>;
+    fn hashed_password(&self) -> Arc<dyn HashedPassword>;
 }
 
 pub struct BaseUser { 
     _public_key: PublicKey,
-    _hashed_password: Rc<dyn HashedPassword>
+    _hashed_password: Arc<dyn HashedPassword>
 }
 
 impl User for BaseUser { 
-    fn authenticate(&self, clear_text_password: Rc<dyn ClearTextPassword>) -> Result<(), std::io::Error> { 
+    fn authenticate(&self, clear_text_password: Arc<dyn ClearTextPassword>) -> Result<(), std::io::Error> { 
         Ok(())
     }
 
@@ -23,13 +23,13 @@ impl User for BaseUser {
         Token::new(String::from("some_token"))
     }
 
-    fn hashed_password(&self) -> Rc<dyn HashedPassword> { 
+    fn hashed_password(&self) -> Arc<dyn HashedPassword> { 
         self._hashed_password.clone()
     }
 }
 
 impl BaseUser { 
-    pub fn new(public_key: PublicKey, hashed_password: Rc<dyn HashedPassword>) -> Self { 
+    pub fn new(public_key: PublicKey, hashed_password: Arc<dyn HashedPassword>) -> Self { 
         BaseUser{_public_key: public_key, _hashed_password: hashed_password}  
     }
 }
